Python API
==========

Spicerack Python API autodoc.

.. automodule:: spicerack

.. autodata:: __version__

.. rubric:: Subpackages and Submodules

.. toctree::

   spicerack.administrative
   spicerack.alerting
   spicerack.alertmanager
   spicerack.confctl
   spicerack.constants
   spicerack.cookbook
   spicerack.debmonitor
   spicerack.decorators
   spicerack.dhcp
   spicerack.dnsdisc
   spicerack.elasticsearch_cluster
   spicerack.exceptions
   spicerack.ganeti
   spicerack.icinga
   spicerack.interactive
   spicerack.ipmi
   spicerack.kafka
   spicerack.mediawiki
   spicerack.mysql
   spicerack.mysql_legacy
   spicerack.netbox
   spicerack.puppet
   spicerack.redfish
   spicerack.redis_cluster
   spicerack.remote
   spicerack.reposync
   spicerack.toolforge
   spicerack.toolforge.etcdctl
   spicerack.typing

.. The private modules spicerack._* are explicitely excluded from the public documentation as they should not be used
   directly by the cookbooks.
